@@ -1,5 +1,4 @@
 /*
- * $Xorg: setvalues.c,v 1.4 2001/02/09 02:05:30 xorgcvs Exp $
  *
 Copyright 1989, 1998  The Open Group
 
@@ -25,7 +24,6 @@ in this Software without prior written authorization from The Open Group.
  *
  * Author:  Chris D. Peterson, MIT X Consortium
  */
-/* $XFree86: xc/programs/editres/setvalues.c,v 1.4 2001/01/17 23:44:52 dawes Exp $ */
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -34,7 +32,7 @@ in this Software without prior written authorization from The Open Group.
 #include <stdio.h>
 
 #include <X11/Xaw/AsciiText.h>
-#include <X11/Xaw/Cardinals.h>	
+#include <X11/Xaw/Cardinals.h>
 #include <X11/Xfuncs.h>
 #include <X11/Xos.h>
 #include "editresP.h"
@@ -57,22 +55,23 @@ PrintSetValuesError(Event *event)
     SetValuesEvent * sv_event = (SetValuesEvent *) event;
     char buf[BUFSIZ];
 
-    if (sv_event->num_entries == 0) 
+    if (sv_event->num_entries == 0)
 	return(XtNewString("SetValues was Successful."));
 
     for (i = 0 ; i < (int)sv_event->num_entries ; i++) {
 	node = FindNode(global_tree_info->top_node,
-			sv_event->info[i].widgets.ids, 
+			sv_event->info[i].widgets.ids,
 			sv_event->info[i].widgets.num_widgets);
 
 	if (node == NULL) {
-	    sprintf(buf, "Editres Internal Error: Unable to FindNode.\n");
-	    AddString(&errors, buf); 
+	    snprintf(buf, sizeof(buf),
+                     "Editres Internal Error: Unable to FindNode.\n");
+	    AddString(&errors, buf);
 	    continue;
 	}
 
-	sprintf(buf, "%s(0x%lx) - %s\n", node->name, node->id,
-		sv_event->info[i].message);
+	snprintf(buf, sizeof(buf), "%s(0x%lx) - %s\n", node->name, node->id,
+                 sv_event->info[i].message);
 	AddString(&errors, buf);
     }
     return(errors);
@@ -101,8 +100,7 @@ GetResourceValueForSetValues(WNode *node, unsigned short *size)
      * the resource database.
      */
 
-    temp = XtMalloc(sizeof(char) * (strlen(ptr) + strlen(RESOURCE_NAME) + 2));
-    sprintf(temp, "%s:%s", RESOURCE_NAME, ptr);
+    XtAsprintf(&temp, "%s:%s", RESOURCE_NAME, ptr);
     XrmPutLineResource(&db, temp);
     XtFree(temp);
 
@@ -111,7 +109,7 @@ GetResourceValueForSetValues(WNode *node, unsigned short *size)
     ptr = XtMalloc(sizeof(char) * value.size);
     memmove( ptr, value.addr, value.size);
     XrmDestroyDatabase(db);
-    
+
     *size = (unsigned short) value.size;
     return(ptr);
 }
